@@ -595,7 +595,10 @@ SEXP path_join(SEXP call, int windows, const char *name, SEXP args, SEXP rho)
     int dots_length = ((TYPEOF(dots) == DOTSXP) ? Rf_length(dots) : 0);
 
 
-    if (dots_length == 0) return Rf_allocVector(STRSXP, 0);
+    if (dots_length == 0) {
+        Rf_unprotect(nprotect);
+        return Rf_allocVector(STRSXP, 0);
+    }
 
 
     SEXP x = Rf_allocVector(VECSXP, dots_length);
@@ -616,7 +619,8 @@ SEXP path_join(SEXP call, int windows, const char *name, SEXP args, SEXP rho)
         /* evaluate each argument of 'dots' */
         xi = CAR(d);
         if (xi == R_MissingArg)
-            Rf_errorcall(call, _("argument is missing, with no default"));
+            // Rf_errorcall(call, _("argument is missing, with no default"));
+            MissingArgError_c("", call, rho, "evalError");
         xi = Rf_eval(xi, rho);
         if (commonLength) {
 
