@@ -11,7 +11,8 @@ SEXP startup_file(Rboolean check_is_valid_init_file_expr, SEXP rho)
     if (promise == R_UnboundValue)
         Rf_error(_("object '%s' not found"), R_CHAR(PRINTNAME(exprSymbol)));
     if (promise == R_MissingArg)
-        Rf_error(_("argument \"%s\" is missing, with no default"), R_CHAR(PRINTNAME(exprSymbol)));
+        // Rf_error(_("argument \"%s\" is missing, with no default"), R_CHAR(PRINTNAME(exprSymbol)));
+        MissingArgError(exprSymbol, R_CurrentExpression, rho, "evalError");
     if (TYPEOF(promise) != PROMSXP)
         Rf_error("invalid '%s', is not a promise", R_CHAR(PRINTNAME(exprSymbol)));
 
