@@ -1,5 +1,5 @@
 stopifnot(identical(
-    this.path:::.is.clipboard(c("clipboard", "clipboard-128", "X11_primary", "X11_secondary", "X11_clipboard")),
+    this.path:::.is_clipboard(c("clipboard", "clipboard-128", "X11_primary", "X11_secondary", "X11_clipboard")),
     if (.Platform$OS.type == "windows")
         c(TRUE , TRUE , FALSE, FALSE, FALSE)
     else
