@@ -78,17 +78,20 @@ main <- function ()
         if (is.null(wd <- getwd())) {
             FALSE
         } else {
-            if (.Platform$OS.type == "windows")
-                wd <- chartr("\\", "/", wd)
+            if (.Platform$OS.type == "windows") {
+                enc <- Encoding(wd)
+                wd <- gsub("\\", "/", wd, fixed = TRUE, useBytes = TRUE)
+                Encoding(wd) <- enc
+            }
             ## we need to know if the package is being installed by 'R CMD build'
             ## (i.e. "installing the package to process help pages")
             ##
             ## we know a package is being installed by 'R CMD build'
             ## if the working directory matches the following pattern
             pattern <- sprintf("/Rtmp[\001-\056\060-\177]{6}/Rbuild[0123456789abcdef]+/%s$", regexQuote(desc["Package"]))
-            ##                   ^^^^^^^^^^^^^^^^^^^^^^^                                 6 ASCII characters excluding \0 and /
-            ##                                                 ^^^^^^^^^^^^^^^^^^^       at least 1 hex digit
-            ##                                                                     ^^^   ends with the package name
+            ##                       ^^^^^^^^^^^^^^^^^^^^^^^                                 6 ASCII characters excluding \0 and /
+            ##                                                     ^^^^^^^^^^^^^^^^^^^       at least 1 hex digit
+            ##                                                                         ^^^   ends with the package name
             grepl(pattern, wd, useBytes = TRUE)
         }
     })
